LookupReferenceStatement

Struct LookupReferenceStatement 

pub struct LookupReferenceStatement {
    pub lookup_name: String,
    pub location: Range<usize>,
}
Represents a lookup ...; statement to include a lookup in a feature.

Fields

lookup_name: String

The name of the lookup to include

Note: unlike in Python’s fontTools, this is simply the name of the lookup rather than a LookupBlock object.

location: Range<usize>

The location of the statement in the source feature file

Implementations

Source

impl LookupReferenceStatement

pub fn new(lookup_name: String, location: Range<usize>) -> Self

Create a new lookup reference statement.