MarkClass

Struct MarkClass 

pub struct MarkClass {
    pub name: SmolStr,
}
The name of a mark class

Note that this differs from the Python fontTools representation. In Python, a MarkClass object contains MarkClassDefinition objects for the glyphs in the class, and the MarkClassDefinition objects recursively refer to the MarkClass they belong to. In Rust, the MarkClass is just a name, and the relationship between the class name and the glyphs and their anchor points is stored at the feature file level.

The name should not begin with @.

Fields

name: SmolStr

The name of the mark class, without the leading @

Implementations

Source

impl MarkClass

pub fn new(name: &str) -> Self

Creates a new MarkClass with the given name.