pub struct MultipleSubstStatement {
pub location: Range<usize>,
pub prefix: Vec<GlyphContainer>,
pub suffix: Vec<GlyphContainer>,
pub glyph: GlyphContainer,
pub replacement: Vec<GlyphContainer>,
pub force_chain: bool,
}Expand description
A multiple substitution (GSUB type 2) statement
Fields
location: Range<usize>The location of the statement in the source FEA.
prefix: Vec<GlyphContainer>The prefix (backtrack) glyphs
suffix: Vec<GlyphContainer>The suffix (lookahead) glyphs
glyph: GlyphContainerThe glyph to be substituted
replacement: Vec<GlyphContainer>The replacement glyphs
force_chain: boolWhether to force this substitution to be treated as contextual
Implementations
Sourceimpl MultipleSubstStatement
impl MultipleSubstStatement
Sourcepub fn new(
glyph: GlyphContainer,
replacement: Vec<GlyphContainer>,
prefix: Vec<GlyphContainer>,
suffix: Vec<GlyphContainer>,
location: Range<usize>,
force_chain: bool,
) -> Self
pub fn new( glyph: GlyphContainer, replacement: Vec<GlyphContainer>, prefix: Vec<GlyphContainer>, suffix: Vec<GlyphContainer>, location: Range<usize>, force_chain: bool, ) -> Self
Create a new multiple substitution statement.