pub struct SinglePosStatement {
pub pos: Vec<(GlyphContainer, Option<ValueRecord>)>,
pub prefix: Vec<GlyphContainer>,
pub suffix: Vec<GlyphContainer>,
pub force_chain: bool,
pub location: Range<usize>,
}Expand description
A single positioning rule (GPOS type 1)
Fields
pos: Vec<(GlyphContainer, Option<ValueRecord>)>The glyphs and their associated value records to be positioned
prefix: Vec<GlyphContainer>The prefix (backtrack) glyphs
suffix: Vec<GlyphContainer>The suffix (lookahead) glyphs
force_chain: boolWhether to force this statement to be treated as a contextual positioning rule
location: Range<usize>The location of the statement in the source feature file
Implementations
Sourceimpl SinglePosStatement
impl SinglePosStatement
Sourcepub fn new(
prefix: Vec<GlyphContainer>,
suffix: Vec<GlyphContainer>,
pos: Vec<(GlyphContainer, Option<ValueRecord>)>,
force_chain: bool,
location: Range<usize>,
) -> Self
pub fn new( prefix: Vec<GlyphContainer>, suffix: Vec<GlyphContainer>, pos: Vec<(GlyphContainer, Option<ValueRecord>)>, force_chain: bool, location: Range<usize>, ) -> Self
Create a new single positioning statement.