SingleSubstStatement

Struct SingleSubstStatement 

pub struct SingleSubstStatement {
    pub location: Range<usize>,
    pub prefix: Vec<GlyphContainer>,
    pub suffix: Vec<GlyphContainer>,
    pub glyphs: Vec<GlyphContainer>,
    pub replacement: Vec<GlyphContainer>,
    pub force_chain: bool,
}
A single substitution (GSUB type 1) statement

Fields

location: Range<usize>

The location of the statement in the source FEA.

prefix: Vec<GlyphContainer>

The prefix (backtrack) glyphs

suffix: Vec<GlyphContainer>

The suffix (lookahead) glyphs

glyphs: Vec<GlyphContainer>

The glyphs to be substituted

Although this is a single substitution, there may be multiple glyphs in e.g. sub [a b] by [c d]; where a and b are both substituted by c and d respectively.

replacement: Vec<GlyphContainer>

The replacement glyphs

force_chain: bool

Whether to force this substitution to be treated as contextual

Implementations

Source

impl SingleSubstStatement

pub fn new( glyphs: Vec<GlyphContainer>, replacement: Vec<GlyphContainer>, prefix: Vec<GlyphContainer>, suffix: Vec<GlyphContainer>, location: Range<usize>, force_chain: bool, ) -> Self

Create a new single substitution statement.

Note the unusual argument order: prefix and suffix come after the replacement glyphs. prefix, suffix, glyphs and replacement should be lists of glyph-containing objects_. glyphs and replacement should be one-item lists.