pub struct MarkClass {
pub name: SmolStr,
}Expand description
The name of a mark class
Note that this differs from the Python fontTools representation. In
Python, a MarkClass object contains MarkClassDefinition objects
for the glyphs in the class, and the MarkClassDefinition objects
recursively refer to the MarkClass they belong to. In Rust, the
MarkClass is just a name, and the relationship between the class name
and the glyphs and their anchor points is stored at the feature file level.
The name should not begin with @.
Fields
name: SmolStrThe name of the mark class, without the leading @
Implementations